@@ -3,14 +3,14 @@
 var path = require('path');
 var util = require('util');
 var cyan = require('ansi-cyan');
-var argv = require('yargs-parser')(process.argv.slice(2));
+var argv = require('minimist')(process.argv.slice(2));
 var Suite = require('benchmarked');
 
 function run(code, fixtures) {
   var suite = new Suite({
     cwd: __dirname,
-    fixtures: `fixtures/${fixtures}.js`,
-    code: `code/${code}*.js`
+    fixtures: 'fixtures/' + fixtures + '.js',
+    code: 'code/' + code + '*.js'
   });
 
   if (argv.dry) {
@@ -18,7 +18,7 @@ function run(code, fixtures) {
       if (/special/.test(fixture.stem)) return;
       console.log(cyan('%s > %s'), code.key, fixture.key);
       var args = require(fixture.path);
-      var res = code.run.apply(null, args).length;
+      var res = code.run.apply(null, args);
       console.log(util.inspect(res, null, 10));
       console.log();
     });
@@ -27,4 +27,4 @@ function run(code, fixtures) {
   }
 }
 
-run(argv._[0] || '*', argv._[1] || '**/{1,2,a}*');
+run(argv._[0] || '*', argv._[1] || '*');
